from setuptools import setup

setup(name='pycohort',
      version='2.1',
      author='Yalim Demirkesen',
      author_linkedin = 'https://www.linkedin.com/in/yalimdemirkesen/',
      description='Visualizing the customer retention rates',
      packages=['pycohort'],
      zip_safe=False)